# email_clients

[![PyPI - Version](https://img.shields.io/pypi/v/email-clients.svg)](https://pypi.org/project/email-clients)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/email-clients.svg)](https://pypi.org/project/email-clients)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install email-clients
```

## License

`email-clients` is distributed under the terms of the [Apache-2.0](https://spdx.org/licenses/Apache-2.0.html) license.
